# binance_historical
For downloading historical data from binance. 

I will prepare the readme soon .. 

[Screencastfrom2024-12-0211-39-31.webm](https://github.com/user-attachments/assets/827e9c0c-16ce-409a-88e8-55fe2e36dace)


It is available on pypi.. For installation run

```
pip install binance-historical
```


